/* ****************************************************************************************************
                                                                                     *
                                                                                                *

/* ADSP-21161 System Register bit definitions */
#include 	"def21161.h"

//.GLOBAL		Amplitude_Modulation;
//.GLOBAL		Init_AM_Buffers;
//.GLOBAL		select_amplitude_freq;
//.GLOBAL		select_signal_frequency;
//.EXTERN 	Left_Channel_In1;
//.EXTERN 	Right_Channel_In1;
//.EXTERN 	Left_Channel_Out0;
//.EXTERN 	Right_Channel_Out0;

.section /dm    amp_modu;

/* AM Control Knobs */
#define WaveSize  	4000 
#define krok 10      		/* sinusoidal wavetable */
//#define Aenv 		0x7FFFFFFF    		/* Aenv = 1 = envelope amplitude */

.var   	sine[WaveSize] = "sinetbl.dat";	/* min frequency f1 = fs/WaveSize = 48k/4k = 12 Hz */
.var    out[WaveSize];
.var    wsp = 2 ;                                 /* load one period of the wavetable */
//.var	cenv = 1;               		/* envelope fenv = cenv * f1 = 2 Hz */
//.var 	c = 600;             			/* signal frequency f = c * f1 = 200 Hz  */
//.var	AM_rate = 6;					
//.var	wavetbl_counter = 0x00000000;
//.var	IRQ1_counter = 10;		
//.var	IRQ2_counter = 10;
//.var Left_Channel_Out0 ;



/* ------------------------------------PROGRAM MEMORY CODE---------------------------------------*/
.section /pm pm_code;

//Init_AM_Buffers:
        Bit Set MODE1 CBUFEN;
		B0 = sine;  					/* pointer for signal generator */
		L0 = @sine;         			/* get size of sine table lookup */
		M0 = krok;		

		B1 = sine;  					/* pointer for signal generator */
		L1 = @sine;         			/* get size of sine table lookup */
		M1 = krok;
		
		B2 = out;
		L2 = @out;
		M2 = 1;
		
				

//		RTS;

//Init_AM_Buffers.end:

/* //////////////////////////////////////////////////////////////////////////////////////////// */
/*                                                                                              */
/*                                   AM Modulation Generator                                    */
/*                                                                                              */
/* //////////////////////////////////////////////////////////////////////////////////////////// */

Amplitude_Modulation:
	/* combine both left and right input samples together into 1 signal */
   	//r0 = dm(Left_Channel_In1);         	/* left input sample */
   	//r1 = dm(Right_Channel_In1);         /* right input sample */
	//r0 = ashift r0 by -1;				/* scale signal by 1/2 for equal mix */
	//r1 = ashift r1 by -1;				/* scale signal by 1/2 for equal mix */
	//r0 = r0 + r1;						/* 1/2xL(n) + 1/2 xR(n) */

//test_wav_update:
	/* update sine value from lookup table? Update every 6 SPORT rx interrupts */
	/* frequency = 6 * c * 4000 / fs = 96000 /48k = ? sec */
//	r11 = DM(AM_rate);					/* count up to 80 interrupts */	
//	r10 = DM(wavetbl_counter);			/* get last count from memory */
//	r10 = r10 + 1;						/* increment preset */
//	comp (r10, r11);					/* compare current count to max count */
//	if ge r10 = r10 - r10;				/* if count equals max, reset to zero and start over */
//	DM(wavetbl_counter) = r10;			/* save updated count */
//
//	r12 = pass r10;						/* test for wave count 0? */
//	if eq jump update_wavetbl_ptr;
    		
	/* if you are here, reuse same wavetable values for now */
//	jump AM_done;

	/* if necessary, calculate updated pointer to wavetable */
	
//update_wavetbl_ptr:
	/*  Calculate A(t) = Aenv * sin(2*pi*fenv*t)      */
//	m0 = DM(cenv);						/* desired increment cenv - frequency f = cenv x fs / WaveSize */
//    r1 = Aenv;							/* Amplitude Envelope */
//    r2 = dm(i0, m0);					/* get next value in wavetable */
//    r3 = r1 * r2 (SSFR);				/* r3 = A(t) = Aenv * sin(2*pi*fenv*t) */

//	if FLAG2_IN jump modulate_audio_input;
//	if NOT FLAG2_IN jump modulate_audio_input;

	/*  Calculate A(t) * sin(2*pi*f*t)   */
//	m1 = DM(c);
    r1 = DM(wsp); 							/* desired increment c - frequency f = c x fs / WaveSize */
    r2 = dm(i1, m1);					/* get next value in wavetable */
    r4 = r1 * r2 (SSFR);				/* r4 = A(t) * sin(2*pi*f*t) */
//	r4 = ASHIFT r4 by -6; 				/* saves your ears when using headphones */
//   	jump AM_done;

//modulate_audio_input:
	/*  Calculate A(t) * x(n) (This is often called a "ring modulator" effect */
  //  r4 = r3 * r0 (SSFR);				/* r4 = A(t) * x(n) */

//AM_done:	   
	/* write output sample to AD1836 Master Codec channels */
   	//dm(Left_Channel_Out0)  = r2;
   	dm(i2, m2)=r4;       	/* left output sample */
 //  	dm(Right_Channel_Out0) = r4;	   	/* right output sample */
			
//	rts;
jump Amplitude_Modulation;

koniec: nop ;
		nop;
		nop;
     jump koniec;

Amplitude_Modulation.end:

